Package 'sapid'

Title: A Strategy to Analyze Plant Extracts Taste In Depth
Description: This package provides the infrastructure to implement a Strategy to Analyze Plant Extracts Taste In Depth.
Authors: Adriano Rutz [aut, cre] (ORCID: <https://orcid.org/0000-0003-0443-9902>)
Maintainer: Adriano Rutz <[email protected]>
License: GPL (>= 3)
Version: 0.0.0.9002
Built: 2026-06-10 11:48:12 UTC
Source: https://github.com/adafede/sapid

Help Index


geom_sigmoid

Description

geom_sigmoid

Usage

geom_sigmoid(
  mapping = NULL,
  data = NULL,
  geom = "line",
  position = "identity",
  na.rm = FALSE,
  show.legend = NA,
  smooth = 8,
  direction = "x",
  inherit.aes = TRUE,
  ...
)

Arguments

mapping

provide you own mapping. both x, xend, y and yend need to be numeric.

data

provide you own data

geom

xhange geom

position

change position

na.rm

remove missing values

show.legend

show legend in plot

smooth

how much smooth should the curve have? More means steeper curve.

direction

the character x or y depending of smoothing direction

inherit.aes

should the geom inherits aestethics

...

other arguments to be passed to the geom

Value

ggplot layer


Get session info

Description

Get session info

Usage

get_session_info(session)

Arguments

session

Session

Examples

NULL

Clean terms

Description

Replace terms in a given string using a dictionary, with intelligent matching and case-insensitive handling.

Usage

harmonize_terms(dictionary, x, mode = "word", fallback = FALSE)

Arguments

dictionary

Path to the dictionary file or a data frame containing replacement terms

x

Character string to be cleaned

mode

Replacement mode: 'word' for word boundary matching, 'substring' for partial matching

fallback

Logical, whether to fall back to original string if no replacements occur

Value

Character string with terms replaced

Examples

## Not run: 
harmonize_terms(
  dictionary = "path/to/dictionary.csv",
  x = "Some text with specific terms"
)

## End(Not run)

Harmonize terms df

Description

Harmonize terms df

Usage

harmonize_terms_df(
  df,
  dictionary_generic_path,
  dictionary_napping_path,
  dictionary_specific_path
)

Arguments

df

Df

dictionary_generic_path

Dictionary generic path

dictionary_napping_path

Dictionary napping path

dictionary_specific_path

Dictionary specific path

Examples

NULL

Load consistent profiles

Description

Load consistent profiles

Usage

load_consistent_profiles(input, min_jury = 2L)

Arguments

input

Input

min_jury

Min jury. Default to 2.

Examples

NULL

Load session

Description

Load session

Usage

load_session(input_dir, session_info, tab)

Arguments

input_dir

Input dir

session_info

Session info

tab

Tab

Examples

NULL