| Title: | A Strategy to Analyze Plant Extracts Taste In Depth |
|---|---|
| Description: | This package provides the infrastructure to implement a Strategy to Analyze Plant Extracts Taste In Depth. |
| Authors: | Adriano Rutz [aut, cre] (ORCID: <https://orcid.org/0000-0003-0443-9902>) |
| Maintainer: | Adriano Rutz <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.0.9002 |
| Built: | 2026-06-10 11:48:12 UTC |
| Source: | https://github.com/adafede/sapid |
geom_sigmoid
geom_sigmoid( mapping = NULL, data = NULL, geom = "line", position = "identity", na.rm = FALSE, show.legend = NA, smooth = 8, direction = "x", inherit.aes = TRUE, ... )geom_sigmoid( mapping = NULL, data = NULL, geom = "line", position = "identity", na.rm = FALSE, show.legend = NA, smooth = 8, direction = "x", inherit.aes = TRUE, ... )
mapping |
provide you own mapping. both x, xend, y and yend need to be numeric. |
data |
provide you own data |
geom |
xhange geom |
position |
change position |
na.rm |
remove missing values |
show.legend |
show legend in plot |
smooth |
how much smooth should the curve have? More means steeper curve. |
direction |
the character x or y depending of smoothing direction |
inherit.aes |
should the geom inherits aestethics |
... |
other arguments to be passed to the geom |
ggplot layer
Get session info
get_session_info(session)get_session_info(session)
session |
Session |
NULLNULL
Replace terms in a given string using a dictionary, with intelligent matching and case-insensitive handling.
harmonize_terms(dictionary, x, mode = "word", fallback = FALSE)harmonize_terms(dictionary, x, mode = "word", fallback = FALSE)
dictionary |
Path to the dictionary file or a data frame containing replacement terms |
x |
Character string to be cleaned |
mode |
Replacement mode: 'word' for word boundary matching, 'substring' for partial matching |
fallback |
Logical, whether to fall back to original string if no replacements occur |
Character string with terms replaced
## Not run: harmonize_terms( dictionary = "path/to/dictionary.csv", x = "Some text with specific terms" ) ## End(Not run)## Not run: harmonize_terms( dictionary = "path/to/dictionary.csv", x = "Some text with specific terms" ) ## End(Not run)
Harmonize terms df
harmonize_terms_df( df, dictionary_generic_path, dictionary_napping_path, dictionary_specific_path )harmonize_terms_df( df, dictionary_generic_path, dictionary_napping_path, dictionary_specific_path )
df |
Df |
dictionary_generic_path |
Dictionary generic path |
dictionary_napping_path |
Dictionary napping path |
dictionary_specific_path |
Dictionary specific path |
NULLNULL
Load consistent profiles
load_consistent_profiles(input, min_jury = 2L)load_consistent_profiles(input, min_jury = 2L)
input |
Input |
min_jury |
Min jury. Default to 2. |
NULLNULL
Load session
load_session(input_dir, session_info, tab)load_session(input_dir, session_info, tab)
input_dir |
Input dir |
session_info |
Session info |
tab |
Tab |
NULLNULL